@@ -328,10 +328,12 @@ class OpenStackProvider(providers.BaseProvider):
                     continue
 
             if 'ad:traffic_in' in extra_attrs:
-                aux_img['network_traffic_in'] = extra_attrs['ad:traffic_in']
+                aux_img['network_traffic_in'] = utils.pythonize_network_info(
+                    extra_attrs['ad:traffic_in'])
 
             if 'ad:traffic_out' in extra_attrs:
-                aux_img['network_traffic_out'] = extra_attrs['ad:traffic_out']
+                aux_img['network_traffic_out'] = utils.pythonize_network_info(
+                    extra_attrs['ad:traffic_out'])
 
             aux_img.update({
                 'image_native_id': img_id,
