@@ -1,3 +1,4 @@
+import json
 import os
 import string
 
@@ -29,3 +30,8 @@ def get_tag_value(xml, tag):
         return xml.getElementsByTagName(tag)[0].firstChild.nodeValue
     else:
         return None
+
+
+def pythonize_network_info(network_info):
+    '''Pythonize network_info string'''
+    return json.loads(network_info.replace(':"', '"').replace("=>", ":"))
